@@ -1,6 +1,6 @@
 package PMLTQ::Commands;
 our $AUTHORITY = 'cpan:MATY';
-$PMLTQ::Commands::VERSION = '1.3.2';
+$PMLTQ::Commands::VERSION = '1.4.0';
 # ABSTRACT: PMLTQ command line interface
 
 use PMLTQ::Base -strict;
@@ -28,6 +28,9 @@ sub DEFAULT_CONFIG {
     isAllLogged => 'false',
     isPublic => 'false',
     isFeatured => 'false',
+    info => {
+      fields => 'name'
+    }
   };
 }
 
@@ -170,13 +173,14 @@ PMLTQ::Commands - PMLTQ command line interface
 
 =head1 VERSION
 
-version 1.3.2
+version 1.4.0
 
 =head1 SYNOPSIS
 
   Usage: pmltq COMMAND [OPTIONS]
 
     pmltq version
+    pmltq configuration
     pmltq init schema1.xml schema2.xml
     pmltq convert
     pmltq load
@@ -184,6 +188,7 @@ version 1.3.2
     pmltq delete
     pmltq webload
     pmltq webdelete
+    pmltq webtreebank
     pmltq webverify
 
   Options (for all commands):
@@ -195,6 +200,12 @@ version 1.3.2
 
 These commands are available by default.
 
+=head2 configuration
+
+  $ pmltq convert
+
+Uses L<PMLTQ::Command::configuration> to to get current configuration
+
 =head2 convert
 
   $ pmltq convert
@@ -231,7 +242,7 @@ Uses L<PMLTQ::Command::load> to load the data generated by C<convert> command
 
 =head2 query
 
-Uses L<PMLTQ::Command::query> to run a query on given treebank. B<Currently doesn't work>
+Uses L<PMLTQ::Command::query> to run a query on given treebank.
 
 =head2 verify
 
@@ -250,6 +261,10 @@ Uses L<PMLTQ::Command::webdelete> to delete treebank from web interface
 
 Uses L<PMLTQ::Command::webload> to load treebank to web interface
 
+=head2 webtreebank
+
+Uses L<PMLTQ::Command::webtreebank> to get list of treebanks or single treebank info
+
 =head2 webverify
 
 Uses L<PMLTQ::Command::webverify> to verify treebank visibility in web interface
